==> affxparser_1.4.1.tar.gz: affxparser/man/readCdf.Rd <==
\name{readCdf}
\alias{readCdf}
\title{Parsing a CDF file using Affymetrix Fusion SDK}

\description{
  This function parses a CDF file using the Affymetrix Fusion SDK.

  \emph{This function will most likely be replaced by the more
        general \code{\link{readCdfUnits}()} function.}
}

\usage{
  readCdf(filename, verbose = 0)
}

\arguments{
  \item{filename}{name of the CDF file.}
  \item{verbose}{how verbose should the output be. 0 means no output,
    with higher numbers being more verbose.}
}

\value{
  A list with one component for each unit. Every component is again a
  list with three components    
  \item{groups}{This is again a list with one component for each group
    (also called block). The information on each group is a list with 5
    components, \code{x}, \code{y}, \code{pbase}, \code{tbase},
  \code{expos}.}
  \item{type}{type of the unit.}
  \item{direction}{direction of the unit.}
}

\note{
  This version of the function does not return information on the QC
  probes. This will be added in a (near) future release. In addition we
  expect the header to be part of the returned object.

  So expect changes to the structure of the value of the function in
  next release. Please contact the developers for details.
}

\author{
  James Bullard, \email{bullard@stat.berkeley.edu} and 
  Kasper Daniel Hansen, \email{khansen@stat.berkeley.edu}
}

\seealso{
  \code{\link{affxparserInfo}} for general information about the
  package/Fusion SDK and \code{\link{readCdfHeader}()} for getting the
  header of a CDF file.
}

\keyword{file}
\keyword{IO}

==> affxparser_1.6.2.tar.gz: affxparser/man/readCdf.Rd <==
\name{readCdf}
\alias{readCdf}
\title{Parsing a CDF file using Affymetrix Fusion SDK}

\description{
  This function parses a CDF file using the Affymetrix Fusion SDK.

  \emph{This function will most likely be replaced by the more
        general \code{\link{readCdfUnits}()} function.}
}

\usage{
  readCdf(filename, units = NULL, verbose = 0)
}

\arguments{
  \item{filename}{name of the CDF file.}
  \item{verbose}{how verbose should the output be. 0 means no output,
    with higher numbers being more verbose.}
}

\value{
  A list with one component for each unit. Every component is again a
  list with three components    
  \item{groups}{This is again a list with one component for each group
    (also called block). The information on each group is a list with 5
    components, \code{x}, \code{y}, \code{pbase}, \code{tbase},
  \code{expos}.}
  \item{type}{type of the unit.}
  \item{direction}{direction of the unit.}
}

\note{
  This version of the function does not return information on the QC
  probes. This will be added in a (near) future release. In addition we
  expect the header to be part of the returned object.

  So expect changes to the structure of the value of the function in
  next release. Please contact the developers for details.
}

\author{
  James Bullard, \email{bullard@stat.berkeley.edu} and 
  Kasper Daniel Hansen, \email{khansen@stat.berkeley.edu}
}

\seealso{
  \code{\link{readCdfHeader}()} for getting the header of a CDF file.
}

\keyword{file}
\keyword{IO}
\keyword{internal}
